@@ -153,6 +153,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Hypothesis",
     "Framework :: IDLE",
     "Framework :: IPython",
+    "Framework :: InvenTree",
     "Framework :: Jupyter",
     "Framework :: Jupyter :: JupyterLab",
     "Framework :: Jupyter :: JupyterLab :: 1",
@@ -181,6 +182,7 @@ sorted_classifiers: List[str] = [
     "Framework :: Odoo :: 16.0",
     "Framework :: Odoo :: 17.0",
     "Framework :: Odoo :: 18.0",
+    "Framework :: Odoo :: 19.0",
     "Framework :: OpenTelemetry",
     "Framework :: OpenTelemetry :: Distros",
     "Framework :: OpenTelemetry :: Exporters",
